---
title: 포트원 결제내역은 어떤 기준으로 집계되나요?
category: 자주 묻는 질문 (일반 문의) > 관리자콘솔 > 관리자콘솔 문의
seo:
  title: 포트원 결제내역은 어떤 기준으로 집계되나요?
  description: 관리자콘솔 결제 상세내역의 집계 기준 안내입니다. 상세내역조회 집계기준, 홈 대시보드 집계기준 등 상세한 정보를 확인해보세요.
  keywords:
    - 관리자콘솔
tags:
  - 관리자콘솔
pgCompanies:
  - 공통
searchTags:
  - 홈대시보드
  - 상태승인시각
  - 결제요청시각
  - 결제상세내역
  - 집계기준
  - 결제내역
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="관리자콘솔 결제 상세내역의 집계 기준을 안내드립니다." />

<Callout content="결제내역은 결제요청시각 / 상태승인시각 으로 집계기준이 구분됩니다." title="미리 알아두기" icon="💡" />



#### **상세내역조회 집계기준**

- 결제 요청 시각 : 결제가 처음 요청된 시각을 기준으로 조회합니다.
- 상태 승인 시각 : 결제상태가 가장 최근에 변경된 시각을 기준으로 조회합니다.
- ex) 결제 1/2 일 / 취소 1/4일 경우 > 조회 날짜를 1/4\~1/4일로 고정하면 \
  **결제 요청 시각** 기준에서는 결과가 나오지 않고 **상태 승인 시각** 기준에서는 결과가 조회 됩니다.

#### **홈 대시보드의 집계기준**

- 기간 동안 승인된 금액을 합계 (그 사이에 결제만 됐다면 무조건 합계포함)
- 기간 동안 취소된 금액을 합계 (그 사이에 결제만 됐다면 무조건 합계포함)
- 순거래액 : 승인 - 취소 합계

#### **홈(대시보드) 집계기준과 비교하기**

- 홈(대시보드)는 **결제 요청 시각 기준**으로만 집계가 되고 있습니다.
- 또한 집계기준과 별개로 홈 화면에는 테스트 결제내역 및 해외결제를 포함하고 있지 않아 (KRW기준으로만 표기) 결제내역과의 차이가 발생될 수 있으며 결제내역에는 필터링 옵션이 존재하므로 필터링에 따라 다르게 조회될 여지가 있습니다.
